@@ -117,6 +117,8 @@ class DBManager(object):
 
     def query(self, sql):
         result = self.execute(sql)
+        if not result:
+            return []
         result = [dict(row) for row in result]
         return result
         
