@@ -7,6 +7,7 @@ import shutil
 import time
 import traceback
 import sys
+import inspect
 
 
 def parse_arguments():
@@ -350,7 +351,44 @@ class Retry(object):
             self._retry = self._retry - 1
         return result
 
+
+
+def print_args(logger=print, stacklevel=2):
+    def decorator(func):
+        def wrapper(*args, **kwargs):
+            if args:
+                kw = {'stacklevel':stacklevel}
+                if logger == print:
+                    kw = {}
+                if logger and callable(logger):
+                    logger(args[-1], **kw)
+            return func(*args, **kwargs)
+        return wrapper
+    return decorator
+
+def print_start_end(logger=print, stacklevel=3):
+    frame = inspect.stack()[1]
+    file_name = frame.filename
+    def decorator(func):
+        def wrapper(*args, **kwargs):
+            kw = {'stacklevel':stacklevel}
+            if logger == print:
+                kw = {}
+            if logger and callable(logger):
+                logger(file_name+' start', **kw)
+            result = func(*args, **kwargs)
+            if logger and callable(logger):
+                logger(file_name+' end', **kw)
+            return result
+        return wrapper
+    return decorator
+
+
+
 if __name__ == '__main__':
-    result = parse_arguments()
-    print(result)
-    pass
+    @print_start_end()
+    def main():
+        result = parse_arguments()
+        print(result)
+        pass
+    main()
